@@ -55,7 +55,7 @@ test_that("Horvitz-Thompson works in simple case", {
   )
 
   expect_equivalent(
-    tidy(ht_simp_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    tidy(ht_simp_no)[c("std.error", "p.value", "conf.low", "conf.high")],
     rep(NA_real_, 4)
   )
 
@@ -123,7 +123,7 @@ test_that("Horvitz-Thompson works in simple case", {
   )
 
   expect_equivalent(
-    tidy(ht_comp_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    tidy(ht_comp_no)[c("std.error", "p.value", "conf.low", "conf.high")],
     rep(NA_real_, 4)
   )
 
@@ -145,12 +145,18 @@ test_that("Horvitz-Thompson works in simple case", {
   y <- dat$y
   z_comp <- dat$z_comp
   ht_glob <- horvitz_thompson(y ~ z_comp, simple = FALSE, condition_prs = pr_comp)
+  ht_rec <- horvitz_thompson(y ~ z_comp, simple = FALSE, condition_prs = 0.4)
 
   expect_equal(
     ht_with,
     ht_glob
   )
 
+  expect_equal(
+    ht_with,
+    ht_rec
+  )
+
   # with declaration
   ht_nod <- horvitz_thompson(y ~ z_comp, ra_declaration = comp_decl)
   ht_d <- horvitz_thompson(y ~ z_comp, data = dat, ra_declaration = comp_decl)
@@ -192,10 +198,20 @@ test_that("Horvitz-Thompson works with clustered data", {
   )
 
   expect_equivalent(
-    tidy(ht_crs_decl_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    tidy(ht_crs_decl_no)[c("std.error", "p.value", "conf.low", "conf.high")],
     rep(NA_real_, 4)
   )
 
+  expect_message(
+    horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_prs = rep(0.5, nrow(dat))),
+    "Assuming simple cluster randomization"
+  )
+
+  expect_message(
+    horvitz_thompson(y ~ z, data = dat, clusters = cl, condition_prs = rep(0.5, nrow(dat)), simple = FALSE),
+    NA
+  )
+
   # Can infer probabilities as well
   expect_equal(
     ht_crs_decl,
@@ -229,7 +245,7 @@ test_that("Horvitz-Thompson works with clustered data", {
   )
 
   expect_equivalent(
-    tidy(ht_srs_decl_no)[c("std.error", "p.value", "ci.lower", "ci.upper")],
+    tidy(ht_srs_decl_no)[c("std.error", "p.value", "conf.low", "conf.high")],
     rep(NA_real_, 4)
   )
 
@@ -340,12 +356,19 @@ test_that("Horvitz-Thompson works with missingness", {
   dat$z <- randomizr::conduct_ra(decl)
   missing_dat <- dat
   missing_dat$y[1] <- NA
-  decl$probabilities_matrix
-  nrow(missing_dat)
+
   expect_error(
-    horvitz_thompson(y ~ z, data = missing_dat, ra_declaration = decl),
+    ht_miss <- horvitz_thompson(y ~ z, data = missing_dat, ra_declaration = decl),
     NA
   )
+
+  expect_error(
+    ht_miss_pr <- horvitz_thompson(y ~ z, data = missing_dat, condition_prs = 0.35, simple = FALSE),
+    NA
+  )
+
+  expect_equal(ht_miss, ht_miss_pr)
+
   # Test that we didn't edit the declaration in the users env
   # Should work a second time
   expect_error(
@@ -471,7 +494,7 @@ test_that("Horvitz-Thompson properly checks arguments and data", {
 
   ht_o <- horvitz_thompson(y ~ z, data = dat, ci = FALSE)
   expect_equivalent(
-    as.matrix(tidy(horvitz_thompson(y ~ z, data = dat, ci = FALSE))[, c("p.value", "ci.lower", "ci.upper")]),
+    as.matrix(tidy(horvitz_thompson(y ~ z, data = dat, ci = FALSE))[, c("p.value", "conf.low", "conf.high")]),
     matrix(NA, nrow = 1, ncol = 3)
   )
 
